Indiana Courts > Appellate Opinions
Keywords: Court, Indiana, Information, Judiciary, Courts, State, Help

INFORMATION FOR... PUBLIC JUDGES CLERKS EDUCATORS PRESS ATTORNEYS COURT STAFF STUDENTS Courts IN.gov
home > law library > appellate opinions |
Indiana Appellate Opinions - Tax Court
These files are in PDF format. To view a PDF file you will need Adobe Acrobat Reader which is available free of charge at Adobe's Website. |
Gary Community School Corporation v. Indiana Department of Local Government Finance 45T10-1104-TA-30 N/A 08/29/14 Gary Community School Corporation v. Indiana Department of Local Government Finance 45T10-1104-TA-30 N/A 08/29/14
Last modified on Wednesday, September, 03, 2014